@@ -4,3 +4,5 @@ from enum import Enum
 class ModelType(Enum):
     TRANSACTION: str = 'transaction'
     SEGMENT: str = 'segment'
+    ERROR: str = 'error'
+    EXCEPTION: str = 'exception'
